@@ -38,13 +38,13 @@ TDboostRESULT CNodeContinuous::PrintSubtree
            (pMissingNode == NULL ? 0.0 : pMissingNode->dPrediction));
 
     for(i=0; i< cIndent; i++) Rprintf("  ");
-    Rprintf("V%d < %f\n",
+    Rprintf("V%ld < %f\n",
            iSplitVar,
            dSplitValue);
     hr = pLeftNode->PrintSubtree(cIndent+1);
 
     for(i=0; i< cIndent; i++) Rprintf("  ");
-    Rprintf("V%d > %f\n",
+    Rprintf("V%ld > %f\n",
            iSplitVar,
            dSplitValue);
     hr = pRightNode->PrintSubtree(cIndent+1);
